@@ -1,26 +1,24 @@
-# copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
+# copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
-set rcsId {$Id: canvhand.tcl,v 1.20 1998/11/08 21:39:33 jfontain Exp $}
+set rcsId {$Id: canvhand.tcl,v 1.24 1998/11/23 21:38:51 jfontain Exp $}
 
 class canvasWindowManager {
 
     class handles {     ;# embed widget in a frame with handles for resizing and moving inside a canvas acting as a window manager
 
-        proc handles {this parentPath args} composite {[new frame $parentPath] $args} {
+        proc handles {this parentPath manager args} composite {[new frame $parentPath] $args} {
             if {[string compare [winfo class $parentPath] Canvas]!=0} {
-                error "parent must be the manager canvas"
+                error {parent must be the manager canvas}
             }
             set ($this,item) [$parentPath create window 0 0 -window $widget::($this,path) -anchor nw]
+            set ($this,manager) $manager
             set ($this,canvas) $parentPath
             composite::complete $this
         }
 
         proc ~handles {this} {
             [set ($this,canvas)] delete [set ($this,item)] outline                       ;# delete canvas items (eventually outline)
-            if {[info exists ($this,bindings)]} {                                                      ;# eventually delete bindings
-                delete [set ($this,bindings)]
-            }
         }
 
         proc options {this} {
@@ -51,14 +49,8 @@ class canvasWindowManager {
             }
             set path $widget::($this,path)
             catch {eval pack forget [pack slaves $path]}                                        ;# eventually forget existing widget
-            if {[info exists ($this,bindings)]} {                                                      ;# eventually delete bindings
-                delete [set ($this,bindings)]
-            }
-            set ($this,bindings) [new bindings $value end]
-            bindings::set [set ($this,bindings)] <Visibility>\
-                "set canvasWindowManager::handles::($this,partiallyObscured) \[string compare %s VisibilityUnobscured\]"
-            raise $value $path
             pack $value -in $path -fill both -expand 1                                                    ;# expand as manager frame
+            stack $this raise                                            ;# newly managed widgets always appear on top of the others
         }
 
         foreach option {-background -relief -borderwidth} {
@@ -115,13 +107,10 @@ class canvasWindowManager {
         }
 
         proc toggleVisibility {this} {
-            if {[set ($this,partiallyObscured)]} {
-                raise $widget::($this,path)                                    ;# place on top is partially hidden by another window
+            if {[canvasWindowManager::raisedOnTop [set ($this,manager)] $composite::($this,-path)]} {
+                stack $this lower                               ;# else place below other windows so they get a chance to be visible
             } else {
-                lower $widget::($this,path)                     ;# else place below other windows so they get a chance to be visible
-            }
-            if {[string length $composite::($this,-path)]>0} {                                           ;# if managed widget exists
-                raise $composite::($this,-path) $widget::($this,path)                                ;# maintain it just above frame
+                stack $this raise                                              ;# place on top if partially hidden by another window
             }
         }
 
@@ -129,10 +118,7 @@ class canvasWindowManager {
             lifoLabel::pop $::messenger
             if {[info exists (motion)]} {                                                              ;# moving or resizing occured
                 updateGeometry $this
-                raise $widget::($this,path)                                          ;# always place frame on top after acting on it
-                if {[string length $composite::($this,-path)]>0} {                                       ;# if managed widget exists
-                    raise $composite::($this,-path) $widget::($this,path)                            ;# maintain it just above frame
-                }
+                stack $this raise                                                   ;# always place widget on top after acting on it
                 unset (motion)
             } else {                                                                                ;# no moving or resizing occured
                 toggleVisibility $this
@@ -228,7 +214,7 @@ class canvasWindowManager {
             lifoLabel::pop $::messenger                                                       ;# remove previous coordinates or size
 
             if {[set (hidden)]} {                                                              ;# make sure outline is fully visible
-                positionOutlineInStackingOrder $this raise
+                stackOutline $this raise
             }
             set canvas [set ($this,canvas)]
             set coordinates [$canvas coords [set ($this,item)]]
@@ -297,12 +283,12 @@ class canvasWindowManager {
                 # items are static because there can be only 1 outline at a time
                 set ($side,item) [$canvas create window 0 0 -window $frame -width 0 -height 0 -anchor nw -tags outline]
             }
-            positionOutlineInStackingOrder $this lower                                ;# hide outline for now and make it fit widget
+            stackOutline $this lower                                                  ;# hide outline for now and make it fit widget
             eval displayOutline $this [$canvas coords [set ($this,item)]]\
                 [winfo width $widget::($this,path)] [winfo height $widget::($this,path)]
         }
 
-        proc positionOutlineInStackingOrder {this order} {                                    ;# order must be either raise or lower
+        proc stackOutline {this order} {                                                      ;# order must be either raise or lower
             set canvas [set ($this,canvas)]
             foreach side {top bottom left right} {
                 $order [$canvas itemcget [set ($side,item)] -window]
@@ -350,6 +336,21 @@ class canvasWindowManager {
             ]
         }
 
+        proc stack {this order} {                                                             ;# order must be either raise or lower
+            $order $widget::($this,path)
+            if {[string length $composite::($this,-path)]>0} {                                           ;# if managed widget exists
+                raise $composite::($this,-path) $widget::($this,path)                                ;# maintain it just above frame
+            }
+            canvasWindowManager::stacked [set ($this,manager)] $composite::($this,-path) [string compare $order lower]
+        }
+
+        proc stackLower {this handles} {                                                ;# invoked by window manager, so no callback
+            lower $widget::($this,path) $widget::($handles,path)
+            if {[string length $composite::($this,-path)]>0} {                                           ;# if managed widget exists
+                raise $composite::($this,-path) $widget::($this,path)                                ;# maintain it just above frame
+            }
+        }
+
     }
 
 }
