@@ -85,7 +85,7 @@ unlimited number of modules, loaded as the application is launched, each
 module interfacing to a specific type of data. The core is written in the
 great Tcl language (at <A HREF="http://www.scriptics.com/">http://www.scriptics.com/</A>)
 using object oriented techniques thanks to the stooop and scwoop packages
-(at <A HREF="http://www.mygale.org/~jfontain/">http://www.mygale.org/~jfontain/</A>).
+(at <A HREF="http://www.multimania.com/jfontain/">http://www.multimania.com/jfontain/</A>).
 The module function is to describe the data that it is also in charge of
 retrieving and formatting. Modules can be written in plain Tcl or use dynamically
 linked libraries written in the C language (modules are packages in the
@@ -127,11 +127,11 @@ menu for more information.
 <H3>
 <A NAME="required"></A>3. Required software</H3>
 If you are using a Linux Redhat system (5.1 or above), then use the moodss
-rpm file (available (starting with 4.4) at <A HREF="http://www.mygale.org/~jfontain/">http://www.mygale.org/~jfontain/</A>)
+rpm file (available (starting with 4.4) at <A HREF="http://www.multimania.com/jfontain/">http://www.multimania.com/jfontain/</A>)
 for installation. It includes all the required software and librairies
 (except Tcl/Tk 8.x, of course). Unless you want to work on the moodss source
 code, you can skip the rest of this section.
-<P>For the current version (5.1), the following packages must be installed
+<P>For the current version (5.2), the following packages must be installed
 before attempting to install moodss (make sure to check the INSTALL file
 for the latest information):
 <UL>
@@ -166,7 +166,7 @@ scwoop version 2.6 or above</LI>
 <LI>
 tkpiechart version 5.2.1 or above</LI>
 </UL>
-at <A HREF="http://www.mygale.org/~jfontain/">http://www.mygale.org/~jfontain/</A>.
+at <A HREF="http://www.multimania.com/jfontain/">http://www.multimania.com/jfontain/</A>.
 <H3>
 <A NAME="architecture"></A>4. Architecture</H3>
 The moodss application is composed of the core software and one or several
@@ -226,7 +226,6 @@ or gracefully quit the moodss application.
 <P>The <I>Options</I> menu (may not exist, see below) contains the <I>Poll
 time</I> entry which when selected launches the corresponding dialog box,
 as shown below:
-<BR>&nbsp;
 <CENTER><PRE><IMG SRC="moodss2.gif" ALT="poll time dialog box" HEIGHT=129 WIDTH=165></PRE></CENTER>
 The user can select a new poll time among the module choices from a spin
 entry widget, or directly type in a new value, as long as it is not smaller
@@ -340,9 +339,6 @@ small window manager functionality is useless, as it behaves like a basic
 window manager (let me know if it does not).
 <P>Here is another shot featuring a free text viewer with loaded <I>cpustats</I>
 and <I>memstats</I> modules:
-<BR>&nbsp;
-<BR>&nbsp;
-<BR>
 <CENTER><PRE><IMG SRC="moodss4.gif" ALT="moodss window with free text data viewer" HEIGHT=464 WIDTH=431></PRE></CENTER>
 The <I>Help</I> menu contains <I>Global</I> help (actually launches an
 embedded HTML viewer with this very document), <I>Modules</I> help which
@@ -464,6 +460,11 @@ For moodss version 5.1 and above, the following information is also saved:
 <LI>
 table viewers column widths</LI>
 </UL>
+For moodss version 5.1 and above, the following information is also saved:
+<UL>
+<LI>
+viewers stacking order (for internal window manager)</LI>
+</UL>
 When using the <I>File Save</I> menu for the first time, and if a file
 name was not specified in the command line, the file selector dialog box
 appears so that the user may choose a file name (with a .moo extension).
