@@ -2,15 +2,18 @@
 # the next line restarts using the interpreter \
 exec wish "$0" "$@"
 
-# copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@mygale.org)
+wm command . [concat $argv0 $argv]                                   ;# for proper window manager (windowmaker for example) behavior
+wm group . .
+
+# copyright (C) 1997-98 Jean-Luc Fontaine (mailto:jfontain@multimania.com)
 # this program is free software: please read the COPYRIGHT file enclosed in this package or use the Help Copyright menu
 
 source utility.tcl
 startGatheringRCSIds
 
-set rcsId {$Id: moodss.tcl,v 1.113 1998/11/15 11:12:40 jfontain Exp $}
+set rcsId {$Id: moodss.tcl,v 1.118 1998/11/24 20:29:32 jfontain Exp $}
 
-set applicationVersion 5.1
+set applicationVersion 5.2
 
 source getopt.tcl
 
@@ -160,6 +163,7 @@ if {[info exists arguments(-f)]} {
     set modules(all) $argv
 }
 set modules(all,string) [commaSeparatedString $modules(all)]
+wm iconname . "moodss $modules(all)"                                                              ;# give the icon a meaningful name
 set readOnly [info exists arguments(-r)]
 set static [info exists arguments(-S)]
 
@@ -316,7 +320,7 @@ proc createDragAndDropZone {parentPath} {
 
     set frame [frame $parentPath.drops]
 
-    set label [label $frame.graph -image [image create photo -data [dataGraph::iconData]]]
+    set label [label $frame.graph -image applicationIcon]
     pack $label -pady 1 -side left
     new dropSite -path $label -formats DATACELLS\
         -command "createCellsViewer dataGraph \$dragSite::data(DATACELLS) 1 $static \$pollTime"
@@ -467,6 +471,10 @@ if {[info exists initializer]} {
     set width 400
     set height 300
 }
+
+image create photo applicationIcon -data [dataGraph::iconData]                                ;# use data graph icon for application
+wm iconwindow . [toplevel .icon]
+pack [label .icon.image -image applicationIcon]
 wm geometry . ${width}x$height
 
 if {!$readOnly} {
@@ -495,12 +503,12 @@ foreach module $modules(all) {
         }
         if {[info exists initializer]} {
             eval composite::configure $table [record::tableOptions $initializer $module $index]
-            foreach {x y width height} [record::tableGeometry $initializer $module $index] {}      ;# used stored geometry for table
+            # use stored window manager initialization data for table
+            foreach {x y width height level} [record::tableWindowManagerData $initializer $module $index] {}
+            manageViewer $table 0 -static $static -setx $x -sety $y -setwidth $width -setheight $height -level $level
         } else {
-            set width {}
-            set height {}
+            manageViewer $table 0 -static $static -setx $x -sety $y
         }
-        manageViewer $table 0 -static $static -setx $x -sety $y -setwidth $width -setheight $height
         set x [expr {$x+$configuration::(xWindowManagerInitialOffset)}]                   ;# offset tables to achieve a nicer layout
         set y [expr {$y+$configuration::(yWindowManagerInitialOffset)}]
         incr index                                                                                      ;# next view for initializer
@@ -510,7 +518,7 @@ foreach module $modules(all) {
 refresh                                                                                                ;# initialize refresh process
 
 if {[info exists initializer]} {                  ;# stored configuration, now that modules data is initialized, create some viewers
-    foreach {class cells x y width height switchedOptions} [record::viewersData $initializer] {
+    foreach {class cells x y width height level switchedOptions} [record::viewersData $initializer] {
         set viewer [eval new $class $canvas $switchedOptions -draggable $draggable]
         foreach list [composite::configure $viewer] {
             if {[string compare [lindex $list 0] -interval]==0} {                                 ;# viewer supports interval option
@@ -519,6 +527,6 @@ if {[info exists initializer]} {                  ;# stored configuration, now t
             }
         }
         viewer::view $viewer $cells
-        manageViewer $viewer 1 -static $static -setx $x -sety $y -setwidth $width -setheight $height
+        manageViewer $viewer 1 -static $static -setx $x -sety $y -setwidth $width -setheight $height -level $level
     }
 }
